BuildJob class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
BuildJob({required String id, required String status, required String owner, required String repo, String? teamId, String? workflowId, String? workflowFileName, String? installationToken, String? commitSha, int? pullRequestNumber, int? runCount, String? latestRunId, String? tagName, String? branch, String? jobKey, String? workflowRunId, List<
String> ? needs, String? githubBaseUrl, String? githubApiBaseUrl, @DateTimeConverter() DateTime? createdAt, @DateTimeConverter() DateTime? updatedAt}) -
constfactory
-
BuildJob.fromJson(Map<
String, dynamic> json) -
factory
Properties
- branch → String?
-
no setterinherited
- commitSha → String?
-
no setterinherited
-
copyWith
→ $BuildJobCopyWith<
BuildJob> -
Create a copy of BuildJob
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- githubApiBaseUrl → String?
-
no setterinherited
- githubBaseUrl → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- installationToken → String?
-
no setterinherited
- jobKey → String?
-
no setterinherited
- latestRunId → String?
-
no setterinherited
-
needs
→ List<
String> ? -
no setterinherited
- owner → String
-
no setterinherited
- pullRequestNumber → int?
-
no setterinherited
- repo → String
-
no setterinherited
- runCount → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
no setterinherited
- tagName → String?
-
no setterinherited
- teamId → String?
-
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
- workflowFileName → String?
-
no setterinherited
- workflowId → String?
-
no setterinherited
- workflowRunId → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BuildJob value)) → TResult -
Available on BuildJob, provided by the BuildJobPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BuildJob value)?) → TResult? -
Available on BuildJob, provided by the BuildJobPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BuildJob value)?, {required TResult orElse()}) → TResult -
Available on BuildJob, provided by the BuildJobPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String status, String owner, String repo, String? teamId, String? workflowId, String? workflowFileName, String? installationToken, String? commitSha, int? pullRequestNumber, int? runCount, String? latestRunId, String? tagName, String? branch, String? jobKey, String? workflowRunId, List< String> ? needs, String? githubBaseUrl, String? githubApiBaseUrl, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult -
Available on BuildJob, provided by the BuildJobPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BuildJob to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String status, String owner, String repo, String? teamId, String? workflowId, String? workflowFileName, String? installationToken, String? commitSha, int? pullRequestNumber, int? runCount, String? latestRunId, String? tagName, String? branch, String? jobKey, String? workflowRunId, List< String> ? needs, String? githubBaseUrl, String? githubApiBaseUrl, DateTime? createdAt, DateTime? updatedAt)) → TResult -
Available on BuildJob, provided by the BuildJobPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String status, String owner, String repo, String? teamId, String? workflowId, String? workflowFileName, String? installationToken, String? commitSha, int? pullRequestNumber, int? runCount, String? latestRunId, String? tagName, String? branch, String? jobKey, String? workflowRunId, List< String> ? needs, String? githubBaseUrl, String? githubApiBaseUrl, DateTime? createdAt, DateTime? updatedAt)?) → TResult? -
Available on BuildJob, provided by the BuildJobPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited